ScopeDispatcher

Struct ScopeDispatcher 

pub struct ScopeDispatcher { /* private fields */ }
Implements a C++-compatible async_dispatcher_t around a fuchsia_async::Scope.

Implementations

Source

impl ScopeDispatcher

pub fn new() -> Arc<Self>

Creates a new ScopeDispatcher on the currently running fuchsia-async executor.

Panics

Panics if this is not run on a fuchsia-async executor context.

pub fn new_on_executor(executor: EHandle) -> Arc<Self>

Creates a new ScopeDispatcher with a new Scope on the given executor.

pub fn as_ptr(&self) -> *const async_dispatcher_t

Get the pointer to the dispatcher callback struct for passing through FFI layers.

pub fn global_handle(&self) -> &EHandle

Gets the global executor handle for this dispatcher.

pub fn as_scope(&self) -> &Scope

Gets the fuchsia_async::Scope of this dispatcher.

pub fn is_shutting_down(&self) -> bool

Returns true if the dispatcher is currently shutting down.

pub fn shutdown(&self) -> ShutdownCompletionFuture<'_>

Starts the dispatcher shutdown. Resolves when all outstanding tasks have been completed or canceled.