pub struct ScopeDispatcher { /* private fields */ }Expand description
Implements a C++-compatible async_dispatcher_t around a fuchsia_async::Scope.
Implementations
Sourceimpl ScopeDispatcher
impl ScopeDispatcher
Sourcepub fn new() -> Arc<Self> ⓘ
pub fn new() -> Arc<Self> ⓘ
Creates a new ScopeDispatcher on the currently running fuchsia-async executor.
Panics
Panics if this is not run on a fuchsia-async executor context.
Sourcepub fn new_on_executor(executor: EHandle) -> Arc<Self> ⓘ
pub fn new_on_executor(executor: EHandle) -> Arc<Self> ⓘ
Creates a new ScopeDispatcher with a new Scope on the given executor.
Sourcepub fn as_ptr(&self) -> *const async_dispatcher_t
pub fn as_ptr(&self) -> *const async_dispatcher_t
Get the pointer to the dispatcher callback struct for passing through FFI layers.
Sourcepub fn global_handle(&self) -> &EHandle
pub fn global_handle(&self) -> &EHandle
Gets the global executor handle for this dispatcher.
Sourcepub fn as_scope(&self) -> &Scope
pub fn as_scope(&self) -> &Scope
Gets the fuchsia_async::Scope of this dispatcher.
Sourcepub fn is_shutting_down(&self) -> bool
pub fn is_shutting_down(&self) -> bool
Returns true if the dispatcher is currently shutting down.
Sourcepub fn shutdown(&self) -> ShutdownCompletionFuture<'_> ⓘ
pub fn shutdown(&self) -> ShutdownCompletionFuture<'_> ⓘ
Starts the dispatcher shutdown. Resolves when all outstanding tasks have been completed or canceled.